@@ -76,6 +76,9 @@ class BaseCode:
         self.var_postfix_enter.set(False)
 
         self.long_note = long_note
+        
+
+        
 
         if code_display is None:
             code_display = code
@@ -94,8 +97,8 @@ class BaseCode:
             self.postit_button.config(image='')
 
     def toggle_postfix_enter(self):
-        r = self.var_postfix_enter.get()
-        self.var_postfix_enter.set(r)
+        #r = self.var_postfix_enter.get()
+        #self.var_postfix_enter.set(r)
         self.update_button_enter_sign()
         
 
@@ -106,6 +109,7 @@ class BaseCode:
         pass
 
     def set_note(self, help_text):
+
         if not self.long_note:
             # use main note
             self.main_note_label.config(text=help_text)
@@ -132,18 +136,18 @@ class BasePost:
         # drag and press event
         self.postit_button.bind("<B1-Motion>", self.on_mouse_drag)
         self.postit_button.bind("<ButtonRelease-1>", self.on_mouse_release)
-        self.postit_button.config(cursor='arrow')
+        #self.postit_button.config(cursor='arrow')
 
     def on_mouse_drag(self, event):
         ###print('drag ...')
         #create drag window
         if not self.drag_window: 
             self.create_drag_window()
-            self.postit_button.config(cursor='hand2')
+            #self.postit_button.config(cursor='hand2')
 
         x_root, y_root = event.x_root, event.y_root
 
-        self.drag_window.geometry('+{}+{}'.format(x_root-10, y_root+10))
+        self.drag_window.geometry('+{}+{}'.format(x_root+2, y_root-5))
 
         #change insert over editor or shell (but not postit button)
         
@@ -203,7 +207,7 @@ class BasePost:
             font = self.postit_button.cget('font')
             bg = self.postit_button.cget('bg')
             fg = self.postit_button.cget('fg')
-            text = '  ' + self.postit_button.cget('text')
+            text = ' ' + self.postit_button.cget('text')
             #self.hover_text_backup = text
             justify = self.postit_button.cget('justify')
             self.drag_button = tk.Button(self.drag_window, text=text, bg=bg, 
@@ -218,7 +222,7 @@ class BasePost:
         if self.drag_window:
             self.drag_window.destroy()
             self.drag_window = None
-            self.postit_button.config(cursor='arrow')
+            #self.postit_button.config(cursor='arrow')
             
         # restore mouse cursor 
 
@@ -415,7 +419,7 @@ class BasePost:
 class BasePopup:
     def popup_init(self):
         self.popup_menu = tk.Menu(self, tearoff=0)
-        self.popup_menu.add_checkbutton(label="加上Enter換行", onvalue=1, offvalue=0, 
+        self.popup_menu.add_checkbutton(label="切換 Enter換行", onvalue=1, offvalue=0, 
                 variable=self.var_postfix_enter,
                 command=self.toggle_postfix_enter,
                 )
