@@ -7,7 +7,7 @@ from keyword import iskeyword
 
 from collections import Counter, namedtuple
 
-
+import tkinter.font as font
 
 # 
 TAB_DATA_PATH = Path(__file__).parent / 'tab_data'
@@ -21,7 +21,7 @@ postit_view = None
 
 ### code namedtuple
 
-CodeNTuple = namedtuple('CodeNTuple','menu_display code code_display note long_note')
+CodeNTuple = namedtuple('CodeNTuple','menu_display code code_display note long_note ')
 
 # image dict
 def load_image(name):
@@ -34,6 +34,7 @@ common_images = {}
 # images for tools
 load_image('enter')
 load_image('enter_small')
+load_image('enter_key')
 load_image('backspace')
 load_image('pilcrow')
 load_image('undo')
@@ -61,15 +62,18 @@ load_image('dropdown_empty')
 load_image('empty')
 load_image('enclosed_right') 
 load_image('enclosed_left') 
-
-
+load_image('block_enclosed') 
+load_image('block_enclosed_small') 
+load_image('note') 
+load_image('paste_postit')
 load_image('gear')
+load_image('info')
 
 #  
 # setup vars counter and default
 
 
-common_default_vars = ['x','y','z','變數','文字','清單','數','索引','項目','字典','i','j']
+common_default_vars = ['x','y','z','數字','文字','清單','數','索引','項目','字典','i','j']
 #common_default_vars =()
 
 # share postit . should be assign carefully
@@ -89,6 +93,18 @@ def disable_var_buttons():
     #share_var_assign_postit.postit_button.config(state='disable')
 
 
+# font
+postit_font = font.Font(size=12, weight=font.NORMAL, family='Consolas') 
+note_font = font.Font(size=10, weight=font.NORMAL, family='Consolas')
+popup_menu_font = font.Font(size=10, weight=font.NORMAL, family='Consolas')
 
 
+dialog_title_font = font.Font(size=14, weight=font.NORMAL, family='Consolas')
+dialog_font = font.Font(size=10, weight=font.NORMAL, family='Consolas')
+
+symbol_font = font.Font(size=10, weight=font.NORMAL, family='Consolas')
+postit_para_font = font.Font(size=11, weight=font.NORMAL, family='Consolas')
+tab_title = font.Font(size=12, weight=font.NORMAL, family='Consolas')
+tab_label = font.Font(size=12, weight=font.NORMAL, family='Consolas')
+
 
