@@ -42,7 +42,7 @@ class VariableMenuWidget(ttk.Frame):
 
         get_workbench().option_add('*TCombobox*Listbox.font', text_font)
 
-        self.vars_combobox = ttk.Combobox(self, width=10, state="readonly", font=text_font,
+        self.vars_combobox = ttk.Combobox(self, width=12, state="readonly", font=text_font,
                 justify=tk.CENTER,textvariable=self.tk_var,takefocus=0,
                 values=[],style="V.TLabel")
 
@@ -55,10 +55,16 @@ class VariableMenuWidget(ttk.Frame):
 
         self.vars_combobox.bind('<<ComboboxSelected>>', self.on_combo_select)
         #self.vars_combobox.bind('<<Selection>>', self.on_select)
+        
         self.vars_combobox.bind('<Button-1>',self.on_combo_click)
 
+        
         #get_workbench().bind("ToplevelResponse", self._handle_toplevel_response, True)
 
+    
+
+
+
     # def empty_vars(self):
     #     self.vars_counter = Counter()
     #     self.update_vars_menu()
@@ -86,6 +92,7 @@ class VariableMenuWidget(ttk.Frame):
     def update_vars_menu(self):
         if len(self.vars_counter):
             vars_list =[v for v,_ in self.vars_counter.most_common(self.vars_limit)]
+            vars_list = sorted(vars_list)
             self.vars_combobox.config(values=vars_list)
             self.vars_combobox.current(0)
             #
@@ -99,19 +106,49 @@ class VariableMenuWidget(ttk.Frame):
 
     def update_vars_option_from_counter(self):
         vars_list =[v for v,_ in self.vars_counter.most_common(self.vars_limit)]
+        vars_list = sorted(vars_list)
         get_workbench().set_option(self.option_name, vars_list)
 
 
     def on_combo_select(self, event):
+        #print('on select')
+        
+        self.selection_clear()
+        
         if self.last_focus is not '':
             self.last_focus.focus_set()
-            
-        self.selection_clear()
+
+        # insert at the same time
+        workbench = get_workbench()
+        focus_widget = workbench.focus_get()
+        if isinstance(focus_widget, CodeViewText):
+            # cursor in editor
+            editor_text = focus_widget 
+            if editor_text.tag_ranges(tk.SEL)  :
+                # has selection
+                common.share_var_get_postit.insert_into_editor(editor_text, 
+                                        pressing=True, selecting=True)
+            else:# no selection
+                common.share_var_get_postit.insert_into_editor(editor_text, 
+                                        pressing=True, selecting=False)
+        elif isinstance(focus_widget, ShellText):
+            # cusor in shell
+            shell_text = focus_widget
+            if shell_text.tag_ranges(tk.SEL):
+                # has selection
+                common.share_var_get_postit.insert_into_shell(shell_text, 
+                                        pressing=True, selecting=True)
+            else:# no selection
+                common.share_var_get_postit.insert_into_shell(shell_text, 
+                                        pressing=True, selecting=False) 
+
+        
 
     def on_combo_click(self, event):
   
         workbench = get_workbench()
         self.last_focus = workbench.focus_get()
+        #print('last_focus: ',self.last_focus )
         #self.selection_clear()
         
     # def _handle_toplevel_response(self, event):
@@ -159,7 +196,7 @@ class VariableMenuPopup:
 
     def delete_all_restore_default(self):
         
-        ans = messagebox.askyesno('刪除變數','刪除所有變數，並恢復預設值嗎？')
+        ans = messagebox.askyesno('刪除變數','刪除所有變數，並恢復預設值嗎？', master=get_workbench())
         #print(ans)
         if ans:
             #print('yes ')
@@ -173,7 +210,7 @@ class VariableMenuPopup:
 
     def delete_all(self):
         if len(self.vars_counter):
-            ans = messagebox.askyesno('清空全部變數','要清空全部變數嗎？')
+            ans = messagebox.askyesno('清空全部變數','要清空全部變數嗎？',master=get_workbench())
             #print(ans)
             if ans:
                 #print('yes ')
@@ -204,6 +241,7 @@ class VariableAddToolPostit(ttk.Frame):
         self.tool_name = 'variable_add'
         self.tool_image = common_images[self.tool_name]
         self.select_text = ''
+        self.select_editor = None
 
         ttk.Frame.__init__(self, master)        
         self.postit_button = tk.Button(self,  
@@ -228,6 +266,7 @@ class VariableAddToolPostit(ttk.Frame):
                         
             # only select within a line
             self.select_text = widget.get(tk.SEL_FIRST,tk.SEL_LAST)
+            self.select_editor = event.widget
             if len(self.select_text) and '\n' not in self.select_text:
                 #print(self.select_text)
                 self.postit_button.config(state='normal')
@@ -250,7 +289,7 @@ class VariableAddToolPostit(ttk.Frame):
             content = '【 ' + target_text + ' 】 不是一個合格的變數名稱\n\n'
             content += '【說明】1.變數名稱可以用的字是文字,底線(_)或數字\n'
             content += '　　　　2.變數名稱的開頭第1個字不可以用數字'
-            messagebox.showwarning('變數名稱錯誤', content)
+            messagebox.showwarning('變數名稱錯誤', content, master=get_workbench())
             return
         # elif iskeyword(self.select_text):
         #     content = '【 ' + self.select_text + ' 】 是python的保留關鍵字\n'
@@ -265,10 +304,23 @@ class VariableAddToolPostit(ttk.Frame):
             vars_postit.update_vars_menu()
             vars_postit.update_vars_option_from_counter()
             vars_postit.tk_var.set(target_text)
-
-
+            
+            # move cursor to var end and cancel selection
+            self.select_editor.mark_set(tk.INSERT, tk.SEL_LAST )
+            self.select_editor.tag_remove(tk.SEL, tk.SEL_FIRST, tk.SEL_LAST)
 
 class VariableFetchToolPostMixin:
+    def post_init(self):
+        self.drag_window = None
+        self.drag_button = None
+        self.drag_hover_selection = False
+        self.hover_text_backup = ''
+        #self.mouse_dragging = False
+        # drag and press event
+        #self.postit_button.bind("<B1-Motion>", self.on_mouse_drag)
+        self.postit_button.bind("<Button-1>", self.on_mouse_release)
+        #self.postit_button.config(cursor='arrow')
+
     def on_mouse_drag(self, event):
         state = self.postit_button.cget('state')
         if  state in ('normal', 'active') :
@@ -293,7 +345,7 @@ class VariableFetchToolPostMixin:
         font = self.postit_button.cget('font')
 
         if self.tool_name == 'variable_get':
-            text = '    ' + common.share_vars_postit.tk_var.get() + ' '
+            text = '      【目前變數】 ' + common.share_vars_postit.tk_var.get() + ' '
         elif self.tool_name == 'variable_assign':
             text = '  ' + common.share_vars_postit.tk_var.get() + ' = '
         elif self.tool_name == 'variable_plus_assign':
@@ -309,7 +361,7 @@ class VariableFetchToolPostMixin:
         elif self.tool_name == 'variable_square':
             text = '  ' + common.share_vars_postit.tk_var.get() + '[] '
         else:
-            text = '  '
+            text = '    '
 
         if self.tool_name == 'variable_get':
             color = '#ffff00'
@@ -317,7 +369,7 @@ class VariableFetchToolPostMixin:
             color = '#5acef8'
 
         self.drag_button = tk.Button(self.drag_window, text=text, bg=color, 
-                    font=font, fg='black', relief='solid', bd=0 )
+                    font=font, fg='black', relief='solid', bd=0, justify='left')
         self.drag_button.pack()
         self.drag_window.overrideredirect(True)
         self.drag_window.attributes('-topmost', 'true')
